@@ -138,19 +138,20 @@ names(vehicles_2022)
 # crashes_2016 = read_collisions(data_dir = d16, filename = "dftRoadSafety_Accidents_2016.csv")
 # crashes_2016_f = format_stats19_2016_ac(crashes_2016)
 # all_crashes = rbind(crashes_2015_f, crashes_2016_f, crashes_2022_f)
-# table(ac$Accident_Severity)
+# table(ac$collision_Severity)
 
 ## ----format-crashes-sf--------------------------------------------------------
 crashes_sf = format_sf(crashes_2022)
 
 ## ----nfatalities--------------------------------------------------------------
+
 library(sf)
 library(dplyr)
-crashes_sf %>% 
-  filter(accident_severity == "Fatal") %>% 
-  select(n_fatalities = accident_index) %>% 
-  aggregate(by = police_boundaries, FUN = length) %>% 
-  plot()
+# crashes_sf %>% 
+#   filter(collision_severity == "Fatal") |> 
+#   select(n_fatalities = collision_index) |> 
+#   aggregate(by = stats19::police_boundaries, FUN = length)
+#   plot()
 
 ## ----ukboundaries-------------------------------------------------------------
 west_yorkshire =
@@ -164,12 +165,12 @@ nrow(crashes_wy)
 ## ----table-join, message = FALSE----------------------------------------------
 library(tidyr)
 library(dplyr)
-sel = casualties_2022$accident_index %in% crashes_wy$accident_index
+sel = casualties_2022$collision_index %in% crashes_wy$collision_index
 casualties_wy = casualties_2022[sel, ]
 table(casualties_wy$casualty_type)
 cas_types = casualties_wy %>% 
-  select(accident_index, casualty_type) %>% 
-  group_by(accident_index) %>% 
+  select(collision_index, casualty_type) %>% 
+  group_by(collision_index) %>% 
   summarise(
     Total = n(),
     walking = sum(casualty_type == "Pedestrian"),
@@ -200,7 +201,7 @@ knitr::include_graphics("wy-overview.jpg")
 ## ----sfplot, fig.show='hold', out.width="100%", fig.cap="Spatial distribution of serious and fatal crashes in West Yorkshire, for cycling, walking, being a car passenger and other modes of travel. Colour is related to the speed limit where the crash happened (red is faster) and size is proportional to the total number of people hurt in each crash (legend not shown).", fig.width=9, fig.height=7----
 library(ggplot2)
 crashes_types = cj %>% 
-  filter(accident_severity != "Slight") %>% 
+  filter(collision_severity != "Slight") %>% 
   mutate(type = case_when(
     walking > 0 ~ "Walking",
     cycling > 0 ~ "Cycling",
@@ -211,7 +212,7 @@ crashes_types$speed_limit = as.integer(crashes_types$speed_limit)
 table(crashes_types$speed_limit)
 ggplot(crashes_types, aes(size = Total, colour = speed_limit)) +
   geom_sf(show.legend = "point", alpha = 0.3) +
-  facet_grid(vars(type), vars(accident_severity)) +
+  facet_grid(vars(type), vars(collision_severity)) +
   scale_size(
     breaks = c(1:3, 12),
     labels = c(1:2, "3+", 12)
@@ -231,7 +232,7 @@ cj %>%
   )) %>% 
   ggplot(aes(colour = speed_limit)) +
   geom_sf() +
-  facet_grid(vars(light), vars(accident_severity)) +
+  facet_grid(vars(light), vars(collision_severity)) +
   scale_color_continuous(low = "blue", high = "red") +
   theme(axis.text = element_blank(), axis.ticks = element_blank())
 
